@@ -1,18 +1,21 @@
-#' Sell notes
+#' Transact with the secondary market
 #'
-#' Sell notes on the FOLIOfn secondary market
+#' Buy or sell notes on the FOLIOfn secondary market
 #'
 #' @param loanId The loan ID
-#' @param orderId the loan's order ID
+#' @param orderId The loan's order ID
 #' @param noteId The loan's note ID
-#' @param expireDate the date the sell offer will expire. Can be as short as the
+#' @param expireDate The date the sell offer will expire. Can be as short as the
 #' current date or up to 7 days from posting the offer. Character string.
-#' @param askingPrice Price you wish to sell your loan for. Remember to consider
+#' @param Price Price you wish to sell your loan for. Remember to consider
 #' the accrued interest in your offering.
 #' @inheritParams AccountSummary
 #' @export
 #'
-FolioSell<- function(loanId, orderId, noteId, expireDate= NULL, askingPrice, LC_CRED=NULL){
+
+
+FolioSell<- function(loanId, orderId, noteId, expireDate= NULL, Price=NULL, LC_CRED=NULL){
+
 
     LC_CRED<-CheckCred(LC_CRED)
 
@@ -28,7 +31,7 @@ FolioSell<- function(loanId, orderId, noteId, expireDate= NULL, askingPrice, LC_
                       "loanId"=loanId,
                       "orderId"= orderId,
                       "noteId"= noteId,
-                      "askingPrice"= askingPrice,
+                      "askingPrice"= Price,
                       stringsAsFactors = F))
 
     LC_POST(postURL,params, LC_CRED$key)
